@@ -10,6 +10,7 @@ Usage::
         GetChannelSchedulePaginator,
         ListAlertsPaginator,
         ListChannelsPaginator,
+        ListLiveSourcesPaginator,
         ListPlaybackConfigurationsPaginator,
         ListPrefetchSchedulesPaginator,
         ListSourceLocationsPaginator,
@@ -23,6 +24,7 @@ Usage::
     get_channel_schedule_paginator: GetChannelSchedulePaginator = client.get_paginator("get_channel_schedule")
     list_alerts_paginator: ListAlertsPaginator = client.get_paginator("list_alerts")
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
+    list_live_sources_paginator: ListLiveSourcesPaginator = client.get_paginator("list_live_sources")
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
     list_prefetch_schedules_paginator: ListPrefetchSchedulesPaginator = client.get_paginator("list_prefetch_schedules")
     list_source_locations_paginator: ListSourceLocationsPaginator = client.get_paginator("list_source_locations")
@@ -34,6 +36,7 @@ from .paginator import (
     GetChannelSchedulePaginator,
     ListAlertsPaginator,
     ListChannelsPaginator,
+    ListLiveSourcesPaginator,
     ListPlaybackConfigurationsPaginator,
     ListPrefetchSchedulesPaginator,
     ListSourceLocationsPaginator,
@@ -48,6 +51,7 @@ __all__ = (
     "GetChannelSchedulePaginator",
     "ListAlertsPaginator",
     "ListChannelsPaginator",
+    "ListLiveSourcesPaginator",
     "ListPlaybackConfigurationsPaginator",
     "ListPrefetchSchedulesPaginator",
     "ListSourceLocationsPaginator",
